import{M as r}from"./Modal.c4a3eb37.js";import{d as a,G as c,r as d,a as _,b as l,er as f,f as n,w as i,bu as u,e as m,v as b}from"./registerWidgets.faec4901.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ece03ce2-4ccd-438c-b330-b766859643ab",e._sentryDebugIdIdentifier="sentry-dbid-ece03ce2-4ccd-438c-b330-b766859643ab")}catch{}})();const p=["src"],y=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=_("router-view");return l(),f(u,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const x=b(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.106195ab.js.map
