import{S as c}from"./Sidebar.1719d735.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.8aef6ab1.js";import{D as l,E as b,F as u}from"./icons.4b27c20b.js";import{d,ey as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./registerWidgets.faec4901.js";import{a as w}from"./asyncComputed.04758d6d.js";import"./gateway.241cb512.js";import{O as z}from"./organization.c8963177.js";import"./index.a999bbce.js";import{B as h}from"./BaseLayout.1ce77a8d.js";import"./Tooltip.865cd6f1.js";import"./logo.084e5d7c.js";import"./passwordlessManager.90d3a316.js";import"./pubsub.c32c984e.js";import"./storage.02df2e1a.js";import"./Text.8913855c.js";import"./Title.38629c7e.js";import"./transButton.389d0ba4.js";import"./index.da74220a.js";import"./index.44ac919e.js";import"./activeRecord.64153c3d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="cf9c528e-bb0f-4660-acb3-0f4c3cc80f2b",o._sentryDebugIdIdentifier="sentry-dbid-cf9c528e-bb0f-4660-acb3-0f4c3cc80f2b")}catch{}})();const J=d({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:b,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.4c6e800a.js.map
