import{m as k,l as S}from"./icons.4b27c20b.js";import{d as f,H as b,b as i,er as n,e as o,bu as g,ez as R,ew as c,eA as v,v as h,G as I,u as _,eu as r,f as N,I as w,c as C,eB as B,eC as $}from"./registerWidgets.faec4901.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="0ae5987d-7aaf-43d2-b42a-c9dc175282d3",a._sentryDebugIdIdentifier="sentry-dbid-0ae5987d-7aaf-43d2-b42a-c9dc175282d3")}catch{}})();const D={class:"sidebar-content"},E={class:"section"},P=["onClick"],U=f({__name:"Sidebar",props:{currentRuntime:{},displaySidebar:{type:Boolean},forceResponsivity:{}},emits:["selectRuntime","closeSidebar"],setup(a,{emit:t}){const d=a,u=b(()=>d.currentRuntime.runtimeType==="dash"),l=s=>{e(s.id)||t("selectRuntime",s)},p=b(()=>d.currentRuntime.sidebar.filter(s=>s.visible)),e=s=>s===d.currentRuntime.id;return(s,y)=>(i(),n("div",{class:c(["sidebar",s.forceResponsivity,{open:s.displaySidebar,dash:u.value}])},[o("div",D,[o("div",E,[(i(!0),n(g,null,R(p.value,m=>(i(),n("div",{key:m.id,class:c(["item",{active:e(m.id)}]),onClick:J=>l(m)},[o("div",{class:c(["item-title",{open:s.displaySidebar}])},v(m.name),3)],10,P))),128))])])],2))}});const T=h(U,[["__scopeId","data-v-09ca60c8"]]),V=a=>(B("data-v-2aa60bdb"),a=a(),$(),a),z={class:"left-side"},A=["d"],F={key:1,class:"brand"},G=["src"],H={key:1,class:"brand-name"},L=V(()=>o("div",null,null,-1)),j={key:0,class:"signed-email"},q=f({__name:"PlayerNavbar",props:{runtime:{},userEmail:{},forceResponsivity:{}},emits:["logout","navigate"],setup(a,{emit:t}){const d=a,u=I({displaySidebar:!1}),l=b(()=>{const e=d.runtime.sidebar;return!e||e.length==0?!1:e.some(s=>s.visible)}),p=e=>t("navigate",e);return(e,s)=>(i(),n(g,null,[l.value||e.runtime.logoUrl||e.runtime.brandName||e.userEmail?(i(),n("div",{key:0,class:c(["navbar",(e.runtime.runtimeType=="dash"||l.value)&&"background"])},[o("div",z,[l.value?(i(),n("svg",{key:0,class:c(["sidebar-menu-icon",e.forceResponsivity,{dash:e.runtime.runtimeType=="dash"}]),viewBox:"0 0 24 24",fill:"var(--color-main)",onClick:s[0]||(s[0]=y=>u.displaySidebar=!u.displaySidebar)},[o("path",{d:_(k)},null,8,A)],2)):r("",!0),e.runtime.logoUrl||e.runtime.brandName?(i(),n("div",F,[e.runtime.logoUrl?(i(),n("img",{key:0,src:e.runtime.logoUrl,class:"logo-image"},null,8,G)):r("",!0),e.runtime.brandName?(i(),n("p",H,v(e.runtime.brandName),1)):r("",!0)])):r("",!0)]),L,e.userEmail?(i(),n("div",j,[o("span",null,v(e.userEmail),1),N(w,{width:"20",height:"20",class:"logout",path:_(S),fill:"var(--color-main)",onClick:s[1]||(s[1]=y=>t("logout"))},null,8,["path"])])):r("",!0)],2)):r("",!0),l.value?(i(),C(T,{key:1,"current-runtime":e.runtime,"display-sidebar":u.displaySidebar,"force-responsivity":e.forceResponsivity,onSelectRuntime:p},null,8,["current-runtime","display-sidebar","force-responsivity"])):r("",!0)],64))}});const O=h(q,[["__scopeId","data-v-2aa60bdb"]]);export{O as P};
//# sourceMappingURL=PlayerNavbar.49b00875.js.map
