import{d,ey as b,H as m,a as g,b as f,c as v,w as i,f as s}from"./registerWidgets.faec4901.js";import{B as _}from"./BaseLayout.1ce77a8d.js";import{a as y}from"./asyncComputed.04758d6d.js";import{P as h}from"./project.30eaff01.js";import"./gateway.241cb512.js";import{O as z}from"./organization.c8963177.js";import"./index.a999bbce.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.8aef6ab1.js";import{S as I}from"./Sidebar.1719d735.js";import{G as w,H as k,I as B,J as P,K as $,L as C,M as D,D as M,E as x,F as L}from"./icons.4b27c20b.js";import"./activeRecord.64153c3d.js";import"./pubsub.c32c984e.js";import"./passwordlessManager.90d3a316.js";import"./storage.02df2e1a.js";import"./logo.084e5d7c.js";import"./Text.8913855c.js";import"./Title.38629c7e.js";import"./transButton.389d0ba4.js";import"./index.da74220a.js";import"./index.44ac919e.js";import"./Tooltip.865cd6f1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="00c682bc-1034-43ee-934a-f069bd11934a",o._sentryDebugIdIdentifier="sentry-dbid-00c682bc-1034-43ee-934a-f069bd11934a")}catch{}})();const ea=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=y(()=>h.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:D,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:x,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ea as default};
//# sourceMappingURL=Project.72cae17a.js.map
