import{v as o,a as r,b as i,c,g as p,h as d,_,i as u,l,T as f,P as h,C as b,M as g,s as y,j as m,k as s,m as v,n as w,p as k}from"./registerWidgets.faec4901.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bd7a2765-034a-41fb-9b0a-93f93947183a",e._sentryDebugIdIdentifier="sentry-dbid-bd7a2765-034a-41fb-9b0a-93f93947183a")}catch{}})();const I={};function A(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",A]]),a=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.79e09581.js"),["assets/Player.79e09581.js","assets/index.dabe2e32.js","assets/registerWidgets.faec4901.js","assets/registerWidgets.74435dfa.css","assets/uuid.ac88a235.js","assets/broker.67a502ef.js","assets/passwordlessManager.90d3a316.js","assets/pubsub.c32c984e.js","assets/storage.02df2e1a.js","assets/Passwordless.961add2f.js","assets/CircularLoading.ca58d6f5.js","assets/CircularLoading.f81b57b4.css","assets/icons.4b27c20b.js","assets/Passwordless.38735f5c.css","assets/executeJs.b1249f30.js","assets/PlayerNavbar.49b00875.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.77469d63.js","assets/Steps.998aa76d.css","assets/Modal.c4a3eb37.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.6243aeb3.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.5737790c.js","assets/broker.54a676ec.css","assets/DashPlayer.66e0598b.js","assets/geometryUtils.146621f7.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.04758d6d.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});f.init(),D.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.bcae06b0.js.map
