import{d as m,ey as d,H as l,b as c,c as u,u as f,v as _}from"./registerWidgets.faec4901.js";import{a as y}from"./asyncComputed.04758d6d.js";import"./gateway.241cb512.js";import{B as g}from"./build.cfc4fe81.js";import"./index.a999bbce.js";import{L as b,N as w}from"./icons.4b27c20b.js";import{r as I}from"./console.d51c41b3.js";import{_ as x}from"./CrudView.vue_vue_type_script_setup_true_lang.3dfdcdc3.js";import{f as v}from"./index.b048d0fb.js";import"./passwordlessManager.90d3a316.js";import"./pubsub.c32c984e.js";import"./storage.02df2e1a.js";import"./activeRecord.64153c3d.js";import"./index.dabe2e32.js";import"./Form.f98578c4.js";import"./FormItem.35215fb3.js";import"./transButton.389d0ba4.js";import"./index.44ac919e.js";import"./index.da74220a.js";import"./index.404475cb.js";import"./index.cf7f7ae3.js";import"./dayjs.dae135e3.js";import"./index.ac358c1e.js";import"./index.3344c224.js";import"./index.b821dc3a.js";import"./index.d3d9557d.js";import"./index.1d42c88f.js";import"./index.353431e1.js";import"./index.176094a8.js";import"./index.bd454869.js";import"./Title.38629c7e.js";import"./Text.8913855c.js";import"./Modal.c4a3eb37.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="c50e1a6c-3d6a-4485-a67d-f53609ade75f",o._sentryDebugIdIdentifier="sentry-dbid-c50e1a6c-3d6a-4485-a67d-f53609ade75f")}catch{}})();const B=m({__name:"Builds",setup(o){const r=d().params.projectId,{loading:s,result:n}=y(()=>g.list(r)),p=l(()=>{var a,i;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(i=(a=n.value)==null?void 0:a.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8)},{text:v(t.createdAt,Date.now(),{addSuffix:!0})},{text:t.status+(t.log?": "+t.log:"")},{text:"",actions:[{icon:b,label:"View logs",onClick:()=>I.push({name:"logs",params:{projectId:r},query:{buildId:t.id}})},{icon:w,label:"Download files",onClick:()=>t.download()}]}]})))!=null?i:[]}});return(a,i)=>(c(),u(x,{"entity-name":"build",loading:f(s),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:p.value},null,8,["loading","table"]))}});const rt=_(B,[["__scopeId","data-v-03f70823"]]);export{rt as default};
//# sourceMappingURL=Builds.b015b61a.js.map
