import{B as i,b as f,T as r,A as g}from"./Title.38629c7e.js";import{U as o,ab as _,f as m,Q as b}from"./registerWidgets.faec4901.js";import{A as h}from"./Text.8913855c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ca36e042-c55f-415b-8da0-fcc91ac86511",e._sentryDebugIdIdentifier="sentry-dbid-ca36e042-c55f-415b-8da0-fcc91ac86511")}catch{}})();var A=globalThis&&globalThis.__rest||function(e,a){var s={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&a.indexOf(t)<0&&(s[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,t=Object.getOwnPropertySymbols(e);n<t.length;n++)a.indexOf(t[n])<0&&Object.prototype.propertyIsEnumerable.call(e,t[n])&&(s[t[n]]=e[t[n]]);return s};const w=()=>b(o(o({},f()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),p=(e,a)=>{let{slots:s,attrs:t}=a;const n=o(o({},e),t),{ellipsis:P,rel:c}=n,y=A(n,["ellipsis","rel"]);_();const d=o(o({},y),{rel:c===void 0&&y.target==="_blank"?"noopener noreferrer":c,ellipsis:!!P,component:"a"});return delete d.navigate,m(i,d,s)};p.displayName="ATypographyLink";p.inheritAttrs=!1;p.props=w();const u=p,O=()=>b(f(),["component"]),l=(e,a)=>{let{slots:s,attrs:t}=a;const n=o(o(o({},e),{component:"div"}),t);return m(i,n,s)};l.displayName="ATypographyParagraph";l.inheritAttrs=!1;l.props=O();const T=l;r.Text=h;r.Title=g;r.Paragraph=T;r.Link=u;r.Base=i;r.install=function(e){return e.component(r.name,r),e.component(r.Text.displayName,h),e.component(r.Title.displayName,g),e.component(r.Paragraph.displayName,T),e.component(r.Link.displayName,u),e};export{T as A,u as L};
//# sourceMappingURL=index.bd454869.js.map
