import{v as t,b as s,er as r}from"./registerWidgets.faec4901.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="2c134458-f206-48f8-b0e7-924746f7df5e",e._sentryDebugIdIdentifier="sentry-dbid-2c134458-f206-48f8-b0e7-924746f7df5e")}catch{}})();const o={},f={class:"organization-settings"};function i(e,n){return s(),r("div",f,"Organization settings")}const c=t(o,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.1bafb43b.js.map
