import"./registerWidgets.faec4901.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},x=new Error().stack;x&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[x]="e3ceab84-8e49-4a73-8ac2-5c871e942b78",e._sentryDebugIdIdentifier="sentry-dbid-e3ceab84-8e49-4a73-8ac2-5c871e942b78")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){const x=Math.random()*16|0;return(e=="x"?x:x&3|8).toString(16)}),o=()=>Math.random().toString(36).slice(2);export{o as r,r as u};
//# sourceMappingURL=uuid.ac88a235.js.map
