import{ab as i,U as t,Q as r,f as p}from"./registerWidgets.faec4901.js";import{B as l,b}from"./Title.38629c7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="4f6a1f65-27c9-43fd-9132-40fb9b60da45",e._sentryDebugIdIdentifier="sentry-dbid-4f6a1f65-27c9-43fd-9132-40fb9b60da45")}catch{}})();const c=()=>t(t({},r(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;i();const f=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return p(l,f,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=c();const g=o;export{g as A};
//# sourceMappingURL=Text.8913855c.js.map
