import{r as a}from"./icons.4b27c20b.js";import{d as r,a as c,b as i,er as d,f as _,u as f,b0 as l,v as u}from"./registerWidgets.faec4901.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="56ea8bc7-e012-4420-b13c-17b223f2f46d",e._sentryDebugIdIdentifier="sentry-dbid-56ea8bc7-e012-4420-b13c-17b223f2f46d")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.17fb9fc5.js.map
