import{P as n}from"./Passwordless.961add2f.js";import{d as r,ex as d,b as i,er as c,f as s,w as _,v as m}from"./registerWidgets.faec4901.js";import{M as f}from"./member.b574c677.js";import{W as p}from"./WidgetsFrame.6243aeb3.js";import"./CircularLoading.ca58d6f5.js";import"./icons.4b27c20b.js";import"./passwordlessManager.90d3a316.js";import"./pubsub.c32c984e.js";import"./storage.02df2e1a.js";import"./gateway.241cb512.js";import"./activeRecord.64153c3d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4909d102-6bea-4ccb-a2c9-adf3a3a16165",e._sentryDebugIdIdentifier="sentry-dbid-4909d102-6bea-4ccb-a2c9-adf3a3a16165")}catch{}})();const l={class:"login"},u=r({__name:"Login",setup(e){const o=d();async function t(a){await f.login(),o.push({name:"home"})}return(a,b)=>(i(),c("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:_(()=>[s(n,{class:"passwordless",onDone:t})]),_:1})]))}});const B=m(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.6267b48f.js.map
